# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import department_pb2 as department__pb2


class DepartmentInterfaceStub(object):
    """Departments
    Each show usually has a few different departments.  Lighting,
    Animation, FX, Hair, and Cloth are the most common. The default
    department is generally the "Unknown" department. Department names
    must be chosen from a list of allowed department names which are
    setup with the AdminStatic interface. This makes the data much more
    consistent when doing reports by department which is important because
    department names are used for production reports.

    Departments get created automatically when the department name property
    is set on a group.

    Using departments, its possible to add shot based cue priorities.  These
    priorities, known as "tasks", can be Track-It managed, or manually
    entered. Track-It managed tasks are added, updated, and removed
    automatically by track it.  When using track-it managed tasks, you must
    provide a minimum number of cores to split up amoung the active tasks.

    -------- Services --------

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddDepartmentName = channel.unary_unary(
                '/department.DepartmentInterface/AddDepartmentName',
                request_serializer=department__pb2.DeptAddDeptNameRequest.SerializeToString,
                response_deserializer=department__pb2.DeptAddDeptNameResponse.FromString,
                )
        self.AddTask = channel.unary_unary(
                '/department.DepartmentInterface/AddTask',
                request_serializer=department__pb2.DeptAddTaskRequest.SerializeToString,
                response_deserializer=department__pb2.DeptAddTaskResponse.FromString,
                )
        self.AddTasks = channel.unary_unary(
                '/department.DepartmentInterface/AddTasks',
                request_serializer=department__pb2.DeptAddTasksRequest.SerializeToString,
                response_deserializer=department__pb2.DeptAddTasksResponse.FromString,
                )
        self.ClearTasks = channel.unary_unary(
                '/department.DepartmentInterface/ClearTasks',
                request_serializer=department__pb2.DeptClearTasksRequest.SerializeToString,
                response_deserializer=department__pb2.DeptClearTasksResponse.FromString,
                )
        self.ClearTaskAdjustments = channel.unary_unary(
                '/department.DepartmentInterface/ClearTaskAdjustments',
                request_serializer=department__pb2.DeptClearTaskAdjustmentsRequest.SerializeToString,
                response_deserializer=department__pb2.DeptClearTaskAdjustmentsResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/department.DepartmentInterface/Delete',
                request_serializer=department__pb2.DeptDeleteRequest.SerializeToString,
                response_deserializer=department__pb2.DeptDeleteResponse.FromString,
                )
        self.DisableTiManaged = channel.unary_unary(
                '/department.DepartmentInterface/DisableTiManaged',
                request_serializer=department__pb2.DeptDisableTiManagedRequest.SerializeToString,
                response_deserializer=department__pb2.DeptDisableTiManagedResponse.FromString,
                )
        self.EnableTiManaged = channel.unary_unary(
                '/department.DepartmentInterface/EnableTiManaged',
                request_serializer=department__pb2.DeptEnableTiManagedRequest.SerializeToString,
                response_deserializer=department__pb2.DeptEnableTiManagedResponse.FromString,
                )
        self.GetDepartmentNames = channel.unary_unary(
                '/department.DepartmentInterface/GetDepartmentNames',
                request_serializer=department__pb2.DeptGetDepartmentNamesRequest.SerializeToString,
                response_deserializer=department__pb2.DeptGetDepartmentNamesResponse.FromString,
                )
        self.GetTasks = channel.unary_unary(
                '/department.DepartmentInterface/GetTasks',
                request_serializer=department__pb2.DeptGetTasksRequest.SerializeToString,
                response_deserializer=department__pb2.DeptGetTasksResponse.FromString,
                )
        self.RemoveDepartmentName = channel.unary_unary(
                '/department.DepartmentInterface/RemoveDepartmentName',
                request_serializer=department__pb2.DeptRemoveDepartmentNameRequest.SerializeToString,
                response_deserializer=department__pb2.DeptRemoveDepartmentNameResponse.FromString,
                )
        self.ReplaceTasks = channel.unary_unary(
                '/department.DepartmentInterface/ReplaceTasks',
                request_serializer=department__pb2.DeptReplaceTaskRequest.SerializeToString,
                response_deserializer=department__pb2.DeptReplaceTaskResponse.FromString,
                )
        self.SetMangedCores = channel.unary_unary(
                '/department.DepartmentInterface/SetMangedCores',
                request_serializer=department__pb2.DeptSetManagedCoresRequest.SerializeToString,
                response_deserializer=department__pb2.DeptSetManagedCoresResponse.FromString,
                )


class DepartmentInterfaceServicer(object):
    """Departments
    Each show usually has a few different departments.  Lighting,
    Animation, FX, Hair, and Cloth are the most common. The default
    department is generally the "Unknown" department. Department names
    must be chosen from a list of allowed department names which are
    setup with the AdminStatic interface. This makes the data much more
    consistent when doing reports by department which is important because
    department names are used for production reports.

    Departments get created automatically when the department name property
    is set on a group.

    Using departments, its possible to add shot based cue priorities.  These
    priorities, known as "tasks", can be Track-It managed, or manually
    entered. Track-It managed tasks are added, updated, and removed
    automatically by track it.  When using track-it managed tasks, you must
    provide a minimum number of cores to split up amoung the active tasks.

    -------- Services --------

    """

    def AddDepartmentName(self, request, context):
        """Add a new department name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTask(self, request, context):
        """Adds a task to this department and return it
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddTasks(self, request, context):
        """Adds a map of tasks to this deparmtment and return them as a list.  Offers a quick way to add many tasks with one
        function.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearTasks(self, request, context):
        """Clears all tasks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearTaskAdjustments(self, request, context):
        """Clears all manual task adjustments to managed tasks.  This won't do anything unless your using Ti Managed tasks.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete the department
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableTiManaged(self, request, context):
        """Disable Track-It management.  This will also clear all tasks.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableTiManaged(self, request, context):
        """Enable Track-It management.  This will pull a task list from Track-It and keep it synced.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDepartmentNames(self, request, context):
        """Return a list of department names
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTasks(self, request, context):
        """Returns the list of tasks for this department.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveDepartmentName(self, request, context):
        """Remove the department of this name
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReplaceTasks(self, request, context):
        """Replaces a map of tasks.  If the task already exists its updated, else its inserted.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetMangedCores(self, request, context):
        """Sets the minimum number of cores for the department to manage between its tasks.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DepartmentInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddDepartmentName': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDepartmentName,
                    request_deserializer=department__pb2.DeptAddDeptNameRequest.FromString,
                    response_serializer=department__pb2.DeptAddDeptNameResponse.SerializeToString,
            ),
            'AddTask': grpc.unary_unary_rpc_method_handler(
                    servicer.AddTask,
                    request_deserializer=department__pb2.DeptAddTaskRequest.FromString,
                    response_serializer=department__pb2.DeptAddTaskResponse.SerializeToString,
            ),
            'AddTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.AddTasks,
                    request_deserializer=department__pb2.DeptAddTasksRequest.FromString,
                    response_serializer=department__pb2.DeptAddTasksResponse.SerializeToString,
            ),
            'ClearTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearTasks,
                    request_deserializer=department__pb2.DeptClearTasksRequest.FromString,
                    response_serializer=department__pb2.DeptClearTasksResponse.SerializeToString,
            ),
            'ClearTaskAdjustments': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearTaskAdjustments,
                    request_deserializer=department__pb2.DeptClearTaskAdjustmentsRequest.FromString,
                    response_serializer=department__pb2.DeptClearTaskAdjustmentsResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=department__pb2.DeptDeleteRequest.FromString,
                    response_serializer=department__pb2.DeptDeleteResponse.SerializeToString,
            ),
            'DisableTiManaged': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableTiManaged,
                    request_deserializer=department__pb2.DeptDisableTiManagedRequest.FromString,
                    response_serializer=department__pb2.DeptDisableTiManagedResponse.SerializeToString,
            ),
            'EnableTiManaged': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableTiManaged,
                    request_deserializer=department__pb2.DeptEnableTiManagedRequest.FromString,
                    response_serializer=department__pb2.DeptEnableTiManagedResponse.SerializeToString,
            ),
            'GetDepartmentNames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDepartmentNames,
                    request_deserializer=department__pb2.DeptGetDepartmentNamesRequest.FromString,
                    response_serializer=department__pb2.DeptGetDepartmentNamesResponse.SerializeToString,
            ),
            'GetTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTasks,
                    request_deserializer=department__pb2.DeptGetTasksRequest.FromString,
                    response_serializer=department__pb2.DeptGetTasksResponse.SerializeToString,
            ),
            'RemoveDepartmentName': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveDepartmentName,
                    request_deserializer=department__pb2.DeptRemoveDepartmentNameRequest.FromString,
                    response_serializer=department__pb2.DeptRemoveDepartmentNameResponse.SerializeToString,
            ),
            'ReplaceTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.ReplaceTasks,
                    request_deserializer=department__pb2.DeptReplaceTaskRequest.FromString,
                    response_serializer=department__pb2.DeptReplaceTaskResponse.SerializeToString,
            ),
            'SetMangedCores': grpc.unary_unary_rpc_method_handler(
                    servicer.SetMangedCores,
                    request_deserializer=department__pb2.DeptSetManagedCoresRequest.FromString,
                    response_serializer=department__pb2.DeptSetManagedCoresResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'department.DepartmentInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DepartmentInterface(object):
    """Departments
    Each show usually has a few different departments.  Lighting,
    Animation, FX, Hair, and Cloth are the most common. The default
    department is generally the "Unknown" department. Department names
    must be chosen from a list of allowed department names which are
    setup with the AdminStatic interface. This makes the data much more
    consistent when doing reports by department which is important because
    department names are used for production reports.

    Departments get created automatically when the department name property
    is set on a group.

    Using departments, its possible to add shot based cue priorities.  These
    priorities, known as "tasks", can be Track-It managed, or manually
    entered. Track-It managed tasks are added, updated, and removed
    automatically by track it.  When using track-it managed tasks, you must
    provide a minimum number of cores to split up amoung the active tasks.

    -------- Services --------

    """

    @staticmethod
    def AddDepartmentName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/AddDepartmentName',
            department__pb2.DeptAddDeptNameRequest.SerializeToString,
            department__pb2.DeptAddDeptNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/AddTask',
            department__pb2.DeptAddTaskRequest.SerializeToString,
            department__pb2.DeptAddTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/AddTasks',
            department__pb2.DeptAddTasksRequest.SerializeToString,
            department__pb2.DeptAddTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/ClearTasks',
            department__pb2.DeptClearTasksRequest.SerializeToString,
            department__pb2.DeptClearTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearTaskAdjustments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/ClearTaskAdjustments',
            department__pb2.DeptClearTaskAdjustmentsRequest.SerializeToString,
            department__pb2.DeptClearTaskAdjustmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/Delete',
            department__pb2.DeptDeleteRequest.SerializeToString,
            department__pb2.DeptDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableTiManaged(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/DisableTiManaged',
            department__pb2.DeptDisableTiManagedRequest.SerializeToString,
            department__pb2.DeptDisableTiManagedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableTiManaged(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/EnableTiManaged',
            department__pb2.DeptEnableTiManagedRequest.SerializeToString,
            department__pb2.DeptEnableTiManagedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDepartmentNames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/GetDepartmentNames',
            department__pb2.DeptGetDepartmentNamesRequest.SerializeToString,
            department__pb2.DeptGetDepartmentNamesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/GetTasks',
            department__pb2.DeptGetTasksRequest.SerializeToString,
            department__pb2.DeptGetTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveDepartmentName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/RemoveDepartmentName',
            department__pb2.DeptRemoveDepartmentNameRequest.SerializeToString,
            department__pb2.DeptRemoveDepartmentNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReplaceTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/ReplaceTasks',
            department__pb2.DeptReplaceTaskRequest.SerializeToString,
            department__pb2.DeptReplaceTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetMangedCores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/department.DepartmentInterface/SetMangedCores',
            department__pb2.DeptSetManagedCoresRequest.SerializeToString,
            department__pb2.DeptSetManagedCoresResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import cue_pb2 as cue__pb2


class CueInterfaceStub(object):
    """Core System level objects and methods

    -------- Services --------]

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetSystemStats = channel.unary_unary(
                '/cue.CueInterface/GetSystemStats',
                request_serializer=cue__pb2.CueGetSystemStatsRequest.SerializeToString,
                response_deserializer=cue__pb2.CueGetSystemStatsResponse.FromString,
                )


class CueInterfaceServicer(object):
    """Core System level objects and methods

    -------- Services --------]

    """

    def GetSystemStats(self, request, context):
        """returns the current server statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CueInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetSystemStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSystemStats,
                    request_deserializer=cue__pb2.CueGetSystemStatsRequest.FromString,
                    response_serializer=cue__pb2.CueGetSystemStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cue.CueInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CueInterface(object):
    """Core System level objects and methods

    -------- Services --------]

    """

    @staticmethod
    def GetSystemStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cue.CueInterface/GetSystemStats',
            cue__pb2.CueGetSystemStatsRequest.SerializeToString,
            cue__pb2.CueGetSystemStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cue.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tcue.proto\x12\x03\x63ue\"\xad\x07\n\x0bSystemStats\x12\x16\n\x0emanage_waiting\x18\x01 \x01(\x05\x12!\n\x19manage_remaining_capacity\x18\x02 \x01(\x05\x12\x16\n\x0emanage_threads\x18\x03 \x01(\x05\x12\x17\n\x0fmanage_executed\x18\x04 \x01(\x03\x12\x17\n\x0fmanage_rejected\x18\x05 \x01(\x03\x12\x18\n\x10\x64ispatch_waiting\x18\x06 \x01(\x05\x12#\n\x1b\x64ispatch_remaining_capacity\x18\x07 \x01(\x05\x12\x18\n\x10\x64ispatch_threads\x18\x08 \x01(\x05\x12\x19\n\x11\x64ispatch_executed\x18\t \x01(\x03\x12\x19\n\x11\x64ispatch_rejected\x18\n \x01(\x03\x12\x16\n\x0ereport_waiting\x18\x0b \x01(\x05\x12!\n\x19report_remaining_capacity\x18\x0c \x01(\x05\x12\x16\n\x0ereport_threads\x18\r \x01(\x05\x12\x17\n\x0freport_executed\x18\x0e \x01(\x03\x12\x17\n\x0freport_rejected\x18\x0f \x01(\x03\x12\x17\n\x0f\x62ooking_waiting\x18\x10 \x01(\x05\x12\"\n\x1a\x62ooking_remaining_capacity\x18\x11 \x01(\x05\x12\x17\n\x0f\x62ooking_threads\x18\x12 \x01(\x05\x12\x1c\n\x14\x62ooking_sleep_millis\x18\x13 \x01(\x05\x12\x18\n\x10\x62ooking_executed\x18\x14 \x01(\x03\x12\x18\n\x10\x62ooking_rejected\x18\x15 \x01(\x03\x12\x1c\n\x14host_balance_success\x18\x16 \x01(\x03\x12\x1b\n\x13host_balance_failed\x18\x17 \x01(\x03\x12\x1d\n\x15killed_offender_procs\x18\x18 \x01(\x03\x12\x18\n\x10killed_oom_procs\x18\x19 \x01(\x03\x12\x15\n\rcleared_procs\x18\x1a \x01(\x03\x12\x16\n\x0e\x62ooking_errors\x18\x1b \x01(\x03\x12\x17\n\x0f\x62ooking_retries\x18\x1c \x01(\x03\x12\x14\n\x0c\x62ooked_procs\x18\x1d \x01(\x03\x12\x14\n\x0creq_for_data\x18\x1e \x01(\x03\x12\x18\n\x10req_for_function\x18\x1f \x01(\x03\x12\x12\n\nreq_errors\x18  \x01(\x03\x12\x16\n\x0eunbooked_procs\x18! \x01(\x03\x12\x17\n\x0fpicked_up_cores\x18\" \x01(\x03\x12\x16\n\x0estranded_cores\x18# \x01(\x03\"\x1a\n\x18\x43ueGetSystemStatsRequest\"<\n\x19\x43ueGetSystemStatsResponse\x12\x1f\n\x05stats\x18\x01 \x01(\x0b\x32\x10.cue.SystemStats2_\n\x0c\x43ueInterface\x12O\n\x0eGetSystemStats\x12\x1d.cue.CueGetSystemStatsRequest\x1a\x1e.cue.CueGetSystemStatsResponseB9\n\x1d\x63om.imageworks.spcue.grpc.cueP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cue_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.imageworks.spcue.grpc.cueP\001Z\026opencue_gateway/gen/go'
  _globals['_SYSTEMSTATS']._serialized_start=19
  _globals['_SYSTEMSTATS']._serialized_end=960
  _globals['_CUEGETSYSTEMSTATSREQUEST']._serialized_start=962
  _globals['_CUEGETSYSTEMSTATSREQUEST']._serialized_end=988
  _globals['_CUEGETSYSTEMSTATSRESPONSE']._serialized_start=990
  _globals['_CUEGETSYSTEMSTATSRESPONSE']._serialized_end=1050
  _globals['_CUEINTERFACE']._serialized_start=1052
  _globals['_CUEINTERFACE']._serialized_end=1147
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: facility.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import host_pb2 as host__pb2
from . import subscription_pb2 as subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x66\x61\x63ility.proto\x12\x08\x66\x61\x63ility\x1a\nhost.proto\x1a\x12subscription.proto\"$\n\x08\x46\x61\x63ility\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x0b\x46\x61\x63ilitySeq\x12&\n\nfacilities\x18\x01 \x03(\x0b\x32\x12.facility.Facility\"\x81\x01\n\nAllocation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61\x63ility\x18\x04 \x01(\t\x12\x10\n\x08\x62illable\x18\x05 \x01(\x08\x12(\n\x05stats\x18\x06 \x01(\x0b\x32\x19.facility.AllocationStats\":\n\rAllocationSeq\x12)\n\x0b\x61llocations\x18\x01 \x03(\x0b\x32\x14.facility.Allocation\"\x97\x02\n\x0f\x41llocationStats\x12\r\n\x05\x63ores\x18\x01 \x01(\x02\x12\x17\n\x0f\x61vailable_cores\x18\x02 \x01(\x02\x12\x12\n\nidle_cores\x18\x03 \x01(\x02\x12\x15\n\rrunning_cores\x18\x04 \x01(\x02\x12\x14\n\x0clocked_cores\x18\x05 \x01(\x02\x12\r\n\x05hosts\x18\x06 \x01(\x05\x12\x14\n\x0clocked_hosts\x18\x07 \x01(\x05\x12\x12\n\ndown_hosts\x18\x08 \x01(\x05\x12\x0c\n\x04gpus\x18\t \x01(\x02\x12\x16\n\x0e\x61vailable_gpus\x18\n \x01(\x02\x12\x11\n\tidle_gpus\x18\x0b \x01(\x02\x12\x14\n\x0crunning_gpus\x18\x0c \x01(\x02\x12\x13\n\x0blocked_gpus\x18\r \x01(\x02\"%\n\x15\x46\x61\x63ilityCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\">\n\x16\x46\x61\x63ilityCreateResponse\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\"%\n\x15\x46\x61\x63ilityDeleteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x18\n\x16\x46\x61\x63ilityDeleteResponse\"E\n\x1d\x46\x61\x63ilityGetAllocationsRequest\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\"N\n\x1e\x46\x61\x63ilityGetAllocationsResponse\x12,\n\x0b\x61llocations\x18\x01 \x01(\x0b\x32\x17.facility.AllocationSeq\"\"\n\x12\x46\x61\x63ilityGetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\";\n\x13\x46\x61\x63ilityGetResponse\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\"O\n\x15\x46\x61\x63ilityRenameRequest\x12$\n\x08\x66\x61\x63ility\x18\x01 \x01(\x0b\x32\x12.facility.Facility\x12\x10\n\x08new_name\x18\x02 \x01(\t\"\x18\n\x16\x46\x61\x63ilityRenameResponse\"U\n\x12\x41llocCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12$\n\x08\x66\x61\x63ility\x18\x03 \x01(\x0b\x32\x12.facility.Facility\"?\n\x13\x41llocCreateResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\">\n\x12\x41llocDeleteRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"\x15\n\x13\x41llocDeleteResponse\" \n\x10\x41llocFindRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"=\n\x11\x41llocFindResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"f\n\x15\x41llocFindHostsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12#\n\x01r\x18\x02 \x01(\x0b\x32\x18.host.HostSearchCriteria\"6\n\x16\x41llocFindHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"\x1d\n\x0f\x41llocGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"<\n\x10\x41llocGetResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"\x14\n\x12\x41llocGetAllRequest\"C\n\x13\x41llocGetAllResponse\x12,\n\x0b\x61llocations\x18\x01 \x01(\x0b\x32\x17.facility.AllocationSeq\"@\n\x14\x41llocGetHostsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"5\n\x15\x41llocGetHostsResponse\x12\x1c\n\x05hosts\x18\x01 \x01(\x0b\x32\r.host.HostSeq\"H\n\x1c\x41llocGetSubscriptionsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"U\n\x1d\x41llocGetSubscriptionsResponse\x12\x34\n\rsubscriptions\x18\x01 \x01(\x0b\x32\x1d.subscription.SubscriptionSeq\"c\n\x19\x41llocReparentHostsRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\x1c\n\x05hosts\x18\x02 \x01(\x0b\x32\r.host.HostSeq\"\x1c\n\x1a\x41llocReparentHostsResponse\"R\n\x17\x41llocSetBillableRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\r\n\x05value\x18\x02 \x01(\x08\"\x1a\n\x18\x41llocSetBillableResponse\"M\n\x13\x41llocSetNameRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x41llocSetNameResponse\"K\n\x12\x41llocSetTagRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\x15\n\x13\x41llocSetTagResponse\"\x18\n\x16\x41llocGetDefaultRequest\"C\n\x17\x41llocGetDefaultResponse\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"B\n\x16\x41llocSetDefaultRequest\x12(\n\nallocation\x18\x01 \x01(\x0b\x32\x14.facility.Allocation\"\x19\n\x17\x41llocSetDefaultResponse2\xa3\x03\n\x11\x46\x61\x63ilityInterface\x12K\n\x06\x43reate\x12\x1f.facility.FacilityCreateRequest\x1a .facility.FacilityCreateResponse\x12K\n\x06\x44\x65lete\x12\x1f.facility.FacilityDeleteRequest\x1a .facility.FacilityDeleteResponse\x12\x42\n\x03Get\x12\x1c.facility.FacilityGetRequest\x1a\x1d.facility.FacilityGetResponse\x12K\n\x06Rename\x12\x1f.facility.FacilityRenameRequest\x1a .facility.FacilityRenameResponse\x12\x63\n\x0eGetAllocations\x12\'.facility.FacilityGetAllocationsRequest\x1a(.facility.FacilityGetAllocationsResponse2\xd6\x08\n\x13\x41llocationInterface\x12G\n\x06\x43reate\x12\x1c.facility.AllocCreateRequest\x1a\x1d.facility.AllocCreateResponse\"\x00\x12\x45\n\x06\x44\x65lete\x12\x1c.facility.AllocDeleteRequest\x1a\x1d.facility.AllocDeleteResponse\x12?\n\x04\x46ind\x12\x1a.facility.AllocFindRequest\x1a\x1b.facility.AllocFindResponse\x12N\n\tFindHosts\x12\x1f.facility.AllocFindHostsRequest\x1a .facility.AllocFindHostsResponse\x12<\n\x03Get\x12\x19.facility.AllocGetRequest\x1a\x1a.facility.AllocGetResponse\x12\x45\n\x06GetAll\x12\x1c.facility.AllocGetAllRequest\x1a\x1d.facility.AllocGetAllResponse\x12K\n\x08GetHosts\x12\x1e.facility.AllocGetHostsRequest\x1a\x1f.facility.AllocGetHostsResponse\x12\x63\n\x10GetSubscriptions\x12&.facility.AllocGetSubscriptionsRequest\x1a\'.facility.AllocGetSubscriptionsResponse\x12Z\n\rReparentHosts\x12#.facility.AllocReparentHostsRequest\x1a$.facility.AllocReparentHostsResponse\x12T\n\x0bSetBillable\x12!.facility.AllocSetBillableRequest\x1a\".facility.AllocSetBillableResponse\x12H\n\x07SetName\x12\x1d.facility.AllocSetNameRequest\x1a\x1e.facility.AllocSetNameResponse\x12\x45\n\x06SetTag\x12\x1c.facility.AllocSetTagRequest\x1a\x1d.facility.AllocSetTagResponse\x12Q\n\nGetDefault\x12 .facility.AllocGetDefaultRequest\x1a!.facility.AllocGetDefaultResponse\x12Q\n\nSetDefault\x12 .facility.AllocSetDefaultRequest\x1a!.facility.AllocSetDefaultResponseB>\n\"com.imageworks.spcue.grpc.facilityP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'facility_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.imageworks.spcue.grpc.facilityP\001Z\026opencue_gateway/gen/go'
  _globals['_FACILITY']._serialized_start=60
  _globals['_FACILITY']._serialized_end=96
  _globals['_FACILITYSEQ']._serialized_start=98
  _globals['_FACILITYSEQ']._serialized_end=151
  _globals['_ALLOCATION']._serialized_start=154
  _globals['_ALLOCATION']._serialized_end=283
  _globals['_ALLOCATIONSEQ']._serialized_start=285
  _globals['_ALLOCATIONSEQ']._serialized_end=343
  _globals['_ALLOCATIONSTATS']._serialized_start=346
  _globals['_ALLOCATIONSTATS']._serialized_end=625
  _globals['_FACILITYCREATEREQUEST']._serialized_start=627
  _globals['_FACILITYCREATEREQUEST']._serialized_end=664
  _globals['_FACILITYCREATERESPONSE']._serialized_start=666
  _globals['_FACILITYCREATERESPONSE']._serialized_end=728
  _globals['_FACILITYDELETEREQUEST']._serialized_start=730
  _globals['_FACILITYDELETEREQUEST']._serialized_end=767
  _globals['_FACILITYDELETERESPONSE']._serialized_start=769
  _globals['_FACILITYDELETERESPONSE']._serialized_end=793
  _globals['_FACILITYGETALLOCATIONSREQUEST']._serialized_start=795
  _globals['_FACILITYGETALLOCATIONSREQUEST']._serialized_end=864
  _globals['_FACILITYGETALLOCATIONSRESPONSE']._serialized_start=866
  _globals['_FACILITYGETALLOCATIONSRESPONSE']._serialized_end=944
  _globals['_FACILITYGETREQUEST']._serialized_start=946
  _globals['_FACILITYGETREQUEST']._serialized_end=980
  _globals['_FACILITYGETRESPONSE']._serialized_start=982
  _globals['_FACILITYGETRESPONSE']._serialized_end=1041
  _globals['_FACILITYRENAMEREQUEST']._serialized_start=1043
  _globals['_FACILITYRENAMEREQUEST']._serialized_end=1122
  _globals['_FACILITYRENAMERESPONSE']._serialized_start=1124
  _globals['_FACILITYRENAMERESPONSE']._serialized_end=1148
  _globals['_ALLOCCREATEREQUEST']._serialized_start=1150
  _globals['_ALLOCCREATEREQUEST']._serialized_end=1235
  _globals['_ALLOCCREATERESPONSE']._serialized_start=1237
  _globals['_ALLOCCREATERESPONSE']._serialized_end=1300
  _globals['_ALLOCDELETEREQUEST']._serialized_start=1302
  _globals['_ALLOCDELETEREQUEST']._serialized_end=1364
  _globals['_ALLOCDELETERESPONSE']._serialized_start=1366
  _globals['_ALLOCDELETERESPONSE']._serialized_end=1387
  _globals['_ALLOCFINDREQUEST']._serialized_start=1389
  _globals['_ALLOCFINDREQUEST']._serialized_end=1421
  _globals['_ALLOCFINDRESPONSE']._serialized_start=1423
  _globals['_ALLOCFINDRESPONSE']._serialized_end=1484
  _globals['_ALLOCFINDHOSTSREQUEST']._serialized_start=1486
  _globals['_ALLOCFINDHOSTSREQUEST']._serialized_end=1588
  _globals['_ALLOCFINDHOSTSRESPONSE']._serialized_start=1590
  _globals['_ALLOCFINDHOSTSRESPONSE']._serialized_end=1644
  _globals['_ALLOCGETREQUEST']._serialized_start=1646
  _globals['_ALLOCGETREQUEST']._serialized_end=1675
  _globals['_ALLOCGETRESPONSE']._serialized_start=1677
  _globals['_ALLOCGETRESPONSE']._serialized_end=1737
  _globals['_ALLOCGETALLREQUEST']._serialized_start=1739
  _globals['_ALLOCGETALLREQUEST']._serialized_end=1759
  _globals['_ALLOCGETALLRESPONSE']._serialized_start=1761
  _globals['_ALLOCGETALLRESPONSE']._serialized_end=1828
  _globals['_ALLOCGETHOSTSREQUEST']._serialized_start=1830
  _globals['_ALLOCGETHOSTSREQUEST']._serialized_end=1894
  _globals['_ALLOCGETHOSTSRESPONSE']._serialized_start=1896
  _globals['_ALLOCGETHOSTSRESPONSE']._serialized_end=1949
  _globals['_ALLOCGETSUBSCRIPTIONSREQUEST']._serialized_start=1951
  _globals['_ALLOCGETSUBSCRIPTIONSREQUEST']._serialized_end=2023
  _globals['_ALLOCGETSUBSCRIPTIONSRESPONSE']._serialized_start=2025
  _globals['_ALLOCGETSUBSCRIPTIONSRESPONSE']._serialized_end=2110
  _globals['_ALLOCREPARENTHOSTSREQUEST']._serialized_start=2112
  _globals['_ALLOCREPARENTHOSTSREQUEST']._serialized_end=2211
  _globals['_ALLOCREPARENTHOSTSRESPONSE']._serialized_start=2213
  _globals['_ALLOCREPARENTHOSTSRESPONSE']._serialized_end=2241
  _globals['_ALLOCSETBILLABLEREQUEST']._serialized_start=2243
  _globals['_ALLOCSETBILLABLEREQUEST']._serialized_end=2325
  _globals['_ALLOCSETBILLABLERESPONSE']._serialized_start=2327
  _globals['_ALLOCSETBILLABLERESPONSE']._serialized_end=2353
  _globals['_ALLOCSETNAMEREQUEST']._serialized_start=2355
  _globals['_ALLOCSETNAMEREQUEST']._serialized_end=2432
  _globals['_ALLOCSETNAMERESPONSE']._serialized_start=2434
  _globals['_ALLOCSETNAMERESPONSE']._serialized_end=2456
  _globals['_ALLOCSETTAGREQUEST']._serialized_start=2458
  _globals['_ALLOCSETTAGREQUEST']._serialized_end=2533
  _globals['_ALLOCSETTAGRESPONSE']._serialized_start=2535
  _globals['_ALLOCSETTAGRESPONSE']._serialized_end=2556
  _globals['_ALLOCGETDEFAULTREQUEST']._serialized_start=2558
  _globals['_ALLOCGETDEFAULTREQUEST']._serialized_end=2582
  _globals['_ALLOCGETDEFAULTRESPONSE']._serialized_start=2584
  _globals['_ALLOCGETDEFAULTRESPONSE']._serialized_end=2651
  _globals['_ALLOCSETDEFAULTREQUEST']._serialized_start=2653
  _globals['_ALLOCSETDEFAULTREQUEST']._serialized_end=2719
  _globals['_ALLOCSETDEFAULTRESPONSE']._serialized_start=2721
  _globals['_ALLOCSETDEFAULTRESPONSE']._serialized_end=2746
  _globals['_FACILITYINTERFACE']._serialized_start=2749
  _globals['_FACILITYINTERFACE']._serialized_end=3168
  _globals['_ALLOCATIONINTERFACE']._serialized_start=3171
  _globals['_ALLOCATIONINTERFACE']._serialized_end=4281
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: criterion.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63riterion.proto\x12\tcriterion\"+\n\x1a\x45qualsFloatSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x02\"-\n\x1c\x45qualsIntegerSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x05\"0\n\x1fGreaterThanFloatSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x02\"2\n!GreaterThanIntegerSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x12\"7\n\x1bInRangeFloatSearchCriterion\x12\x0b\n\x03min\x18\x01 \x01(\x02\x12\x0b\n\x03max\x18\x02 \x01(\x02\"9\n\x1dInRangeIntegerSearchCriterion\x12\x0b\n\x03min\x18\x01 \x01(\x12\x12\x0b\n\x03max\x18\x02 \x01(\x12\"-\n\x1cLessThanFloatSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x02\"/\n\x1eLessThanIntegerSearchCriterion\x12\r\n\x05value\x18\x01 \x01(\x12\x42?\n#com.imageworks.spcue.grpc.criterionP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'criterion_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.imageworks.spcue.grpc.criterionP\001Z\026opencue_gateway/gen/go'
  _globals['_EQUALSFLOATSEARCHCRITERION']._serialized_start=30
  _globals['_EQUALSFLOATSEARCHCRITERION']._serialized_end=73
  _globals['_EQUALSINTEGERSEARCHCRITERION']._serialized_start=75
  _globals['_EQUALSINTEGERSEARCHCRITERION']._serialized_end=120
  _globals['_GREATERTHANFLOATSEARCHCRITERION']._serialized_start=122
  _globals['_GREATERTHANFLOATSEARCHCRITERION']._serialized_end=170
  _globals['_GREATERTHANINTEGERSEARCHCRITERION']._serialized_start=172
  _globals['_GREATERTHANINTEGERSEARCHCRITERION']._serialized_end=222
  _globals['_INRANGEFLOATSEARCHCRITERION']._serialized_start=224
  _globals['_INRANGEFLOATSEARCHCRITERION']._serialized_end=279
  _globals['_INRANGEINTEGERSEARCHCRITERION']._serialized_start=281
  _globals['_INRANGEINTEGERSEARCHCRITERION']._serialized_end=338
  _globals['_LESSTHANFLOATSEARCHCRITERION']._serialized_start=340
  _globals['_LESSTHANFLOATSEARCHCRITERION']._serialized_end=385
  _globals['_LESSTHANINTEGERSEARCHCRITERION']._serialized_start=387
  _globals['_LESSTHANINTEGERSEARCHCRITERION']._serialized_end=434
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: renderPartition.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15renderPartition.proto\x12\x0frenderPartition\"\xb9\x02\n\x0fRenderPartition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03job\x18\x02 \x01(\t\x12\r\n\x05layer\x18\x03 \x01(\t\x12\r\n\x05\x66rame\x18\x04 \x01(\t\x12>\n\x10render_part_type\x18\x05 \x01(\x0e\x32$.renderPartition.RenderPartitionType\x12\x0c\n\x04host\x18\x06 \x01(\t\x12\r\n\x05\x63ores\x18\x07 \x01(\x05\x12\x0e\n\x06memory\x18\x08 \x01(\x03\x12\x11\n\tmax_cores\x18\t \x01(\x05\x12\x12\n\nmax_memory\x18\n \x01(\x03\x12\x16\n\x0emax_gpu_memory\x18\x0b \x01(\x03\x12\x0f\n\x07threads\x18\x0c \x01(\x05\x12\x0c\n\x04gpus\x18\r \x01(\x05\x12\x10\n\x08max_gpus\x18\x0e \x01(\x05\x12\x12\n\ngpu_memory\x18\x0f \x01(\x03\"Q\n\x12RenderPartitionSeq\x12;\n\x11render_partitions\x18\x01 \x03(\x0b\x32 .renderPartition.RenderPartition\"U\n\x17RenderPartDeleteRequest\x12:\n\x10render_partition\x18\x01 \x01(\x0b\x32 .renderPartition.RenderPartition\"\x1a\n\x18RenderPartDeleteResponse\"\x9f\x01\n RenderPartSetMaxResourcesRequest\x12:\n\x10render_partition\x18\x01 \x01(\x0b\x32 .renderPartition.RenderPartition\x12\r\n\x05\x63ores\x18\x02 \x01(\x05\x12\x0e\n\x06memory\x18\x03 \x01(\x03\x12\x12\n\ngpu_memory\x18\x04 \x01(\x03\x12\x0c\n\x04gpus\x18\x05 \x01(\x05\"#\n!RenderPartSetMaxResourcesResponse*R\n\x13RenderPartitionType\x12\x11\n\rJOB_PARTITION\x10\x00\x12\x13\n\x0fLAYER_PARTITION\x10\x01\x12\x13\n\x0f\x46RAME_PARTITION\x10\x02\x32\xf3\x01\n\x18RenderPartitionInterface\x12]\n\x06\x44\x65lete\x12(.renderPartition.RenderPartDeleteRequest\x1a).renderPartition.RenderPartDeleteResponse\x12x\n\x0fSetMaxResources\x12\x31.renderPartition.RenderPartSetMaxResourcesRequest\x1a\x32.renderPartition.RenderPartSetMaxResourcesResponseBE\n)com.imageworks.spcue.grpc.renderpartitionP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'renderPartition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.imageworks.spcue.grpc.renderpartitionP\001Z\026opencue_gateway/gen/go'
  _globals['_RENDERPARTITIONTYPE']._serialized_start=755
  _globals['_RENDERPARTITIONTYPE']._serialized_end=837
  _globals['_RENDERPARTITION']._serialized_start=43
  _globals['_RENDERPARTITION']._serialized_end=356
  _globals['_RENDERPARTITIONSEQ']._serialized_start=358
  _globals['_RENDERPARTITIONSEQ']._serialized_end=439
  _globals['_RENDERPARTDELETEREQUEST']._serialized_start=441
  _globals['_RENDERPARTDELETEREQUEST']._serialized_end=526
  _globals['_RENDERPARTDELETERESPONSE']._serialized_start=528
  _globals['_RENDERPARTDELETERESPONSE']._serialized_end=554
  _globals['_RENDERPARTSETMAXRESOURCESREQUEST']._serialized_start=557
  _globals['_RENDERPARTSETMAXRESOURCESREQUEST']._serialized_end=716
  _globals['_RENDERPARTSETMAXRESOURCESRESPONSE']._serialized_start=718
  _globals['_RENDERPARTSETMAXRESOURCESRESPONSE']._serialized_end=753
  _globals['_RENDERPARTITIONINTERFACE']._serialized_start=840
  _globals['_RENDERPARTITIONINTERFACE']._serialized_end=1083
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: task.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntask.proto\x12\x04task\"w\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04shot\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65pt\x18\x04 \x01(\t\x12\x10\n\x08point_id\x18\x05 \x01(\t\x12\x11\n\tmin_cores\x18\x06 \x01(\x02\x12\x14\n\x0c\x61\x64just_cores\x18\x07 \x01(\x02\"$\n\x07TaskSeq\x12\x19\n\x05tasks\x18\x01 \x03(\x0b\x32\n.task.Task\"7\n\x1bTaskClearAdjustmentsRequest\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\"\x1e\n\x1cTaskClearAdjustmentsResponse\"-\n\x11TaskDeleteRequest\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\"\x14\n\x12TaskDeleteResponse\"I\n\x16TaskSetMinCoresRequest\x12\x18\n\x04task\x18\x01 \x01(\x0b\x32\n.task.Task\x12\x15\n\rnew_min_cores\x18\x02 \x01(\x02\"\x19\n\x17TaskSetMinCoresResponse2\xf3\x01\n\rTaskInterface\x12Y\n\x10\x43learAdjustments\x12!.task.TaskClearAdjustmentsRequest\x1a\".task.TaskClearAdjustmentsResponse\x12;\n\x06\x44\x65lete\x12\x17.task.TaskDeleteRequest\x1a\x18.task.TaskDeleteResponse\x12J\n\x0bSetMinCores\x12\x1c.task.TaskSetMinCoresRequest\x1a\x1d.task.TaskSetMinCoresResponseB:\n\x1e\x63om.imageworks.spcue.grpc.taskP\x01Z\x16opencue_gateway/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.imageworks.spcue.grpc.taskP\001Z\026opencue_gateway/gen/go'
  _globals['_TASK']._serialized_start=20
  _globals['_TASK']._serialized_end=139
  _globals['_TASKSEQ']._serialized_start=141
  _globals['_TASKSEQ']._serialized_end=177
  _globals['_TASKCLEARADJUSTMENTSREQUEST']._serialized_start=179
  _globals['_TASKCLEARADJUSTMENTSREQUEST']._serialized_end=234
  _globals['_TASKCLEARADJUSTMENTSRESPONSE']._serialized_start=236
  _globals['_TASKCLEARADJUSTMENTSRESPONSE']._serialized_end=266
  _globals['_TASKDELETEREQUEST']._serialized_start=268
  _globals['_TASKDELETEREQUEST']._serialized_end=313
  _globals['_TASKDELETERESPONSE']._serialized_start=315
  _globals['_TASKDELETERESPONSE']._serialized_end=335
  _globals['_TASKSETMINCORESREQUEST']._serialized_start=337
  _globals['_TASKSETMINCORESREQUEST']._serialized_end=410
  _globals['_TASKSETMINCORESRESPONSE']._serialized_start=412
  _globals['_TASKSETMINCORESRESPONSE']._serialized_end=437
  _globals['_TASKINTERFACE']._serialized_start=440
  _globals['_TASKINTERFACE']._serialized_end=683
# @@protoc_insertion_point(module_scope)